@@ -160,7 +160,7 @@ static void getlog (char **syslog,const char *ident,const char *facility)
    fmterr ("%s: invalid syslog facility: %s\n",ident,facility);
 }
 
-static void getlevel (uint32_t *level,const char *ident,const char *str)
+static void getlevel (int *level,const char *ident,const char *str)
 {
    static const char *loglevels[] =
 	 {
