@@ -35,6 +35,7 @@
 #include <debug/memory.h>
 
 #include <tinysnmp/tinysnmp.h>
+#include <tinysnmp/unaligned.h>
 #include <tinysnmp/agent/odb.h>
 
 struct node
@@ -80,7 +81,7 @@ static void snmp_free_value (snmp_value_t *value)
 
 static int snmp_copy_value (snmp_value_t *dest,const snmp_value_t *src)
 {
-   memcpy (dest,src,sizeof (snmp_value_t));
+   copy_unaligned (dest,src);
 
    if (src->type == BER_OCTET_STRING)
 	 {
@@ -145,7 +146,7 @@ static struct odb *tree_create (node_t type,const struct node *node)
    odb->parent = odb->sibling = odb->child = NULL;
 
    if (type == VALUE)
-	 odb->data.value = node->value;
+	 copy_unaligned (&odb->data.value,&node->value);
    else
 	 odb->data.node = node->oid[0];
 
