@@ -112,7 +112,7 @@ int snmp_init_addr (snmp_agent_t *agent,char *host)
 void snmp_init_community (snmp_agent_t *agent,char *string)
 {
    assert (agent != NULL && string != NULL);
-   agent->community.buf = string;
+   agent->community.buf = (uint8_t *) string;
    agent->community.len = strlen (string);
 }
 
