@@ -34,6 +34,7 @@
 #include <tinysnmp/tinysnmp.h>
 #include <tinysnmp/agent/module.h>
 #include <tinysnmp/agent/odb.h>
+#include <tinysnmp/unaligned.h>
 
 #include <ber/ber.h>
 
@@ -115,14 +116,14 @@ static void diskDev (snmp_value_t *value,const struct diskinfo *disk)
 {
    value->type = BER_OCTET_STRING;
    value->data.OCTET_STRING.len = strlen (disk->d_dev);
-   value->data.OCTET_STRING.buf = disk->d_dev;
+   value->data.OCTET_STRING.buf = (uint8_t *) disk->d_dev;
 }
 
 static void diskDir (snmp_value_t *value,const struct diskinfo *disk)
 {
    value->type = BER_OCTET_STRING;
    value->data.OCTET_STRING.len = strlen (disk->d_dir);
-   value->data.OCTET_STRING.buf = disk->d_dir;
+   value->data.OCTET_STRING.buf = (uint8_t *) disk->d_dir;
 }
 
 static void diskFSType (snmp_value_t *value,const struct diskinfo *disk)
@@ -134,13 +135,13 @@ static void diskFSType (snmp_value_t *value,const struct diskinfo *disk)
 static void diskTotal (snmp_value_t *value,const struct diskinfo *disk)
 {
    value->type = BER_Gauge32;
-   value->data.Gauge32 = disk->d_total;
+   copy_unaligned (&value->data.Gauge32,&disk->d_total);
 }
 
 static void diskFree (snmp_value_t *value,const struct diskinfo *disk)
 {
    value->type = BER_Gauge32;
-   value->data.Gauge32 = disk->d_free;
+   copy_unaligned (&value->data.Gauge32,&disk->d_free);
 }
 
 static int storage_update (struct odb **odb)
@@ -193,7 +194,7 @@ static void loadDescr (snmp_value_t *value,size_t n)
 {
    value->type = BER_OCTET_STRING;
    value->data.OCTET_STRING.len = strlen (load.descr[n]);
-   value->data.OCTET_STRING.buf = load.descr[n];
+   value->data.OCTET_STRING.buf = (uint8_t *) load.descr[n];
 }
 
 static void loadValue (snmp_value_t *value,size_t n)
